from unittest                                                       import TestCase
from cbr_shared.aws.s3.S3_DB_Base                                   import ENV_NAME__USE_MINIO_AS_S3
from cbr_shared.cbr_backend.server_requests.S3__Server_Request      import S3__Server_Request

from cbr_shared.cbr_sites.CBR_Site__Shared_Objects                  import cbr_site_shared_objects
from cbr_shared.config.Server_Config__CBR_Website                   import server_config__cbr_website
from osbot_aws.testing.Temp__Random__AWS_Credentials                import Temp__Random__AWS_Credentials
from osbot_fast_api.utils.testing.Mock_Obj__Fast_API__Request_Data  import Mock_Obj__Fast_API__Request_Data


class TestCase__CBR__Temp_Chat_Threads(TestCase):

    @classmethod
    def setUpClass(cls):
        assert server_config__cbr_website.cbr_config_active().config_file_name == 'cbr-website.community.toml'      # confirm the config file that we are using
        assert server_config__cbr_website.s3_log_requests()                    is False                             # confirm s3_log_requests is not set
        server_config__cbr_website.cbr_config().cbr_website.s3_log_requests    = True                               # set s3_log_requests

        cls.extra_env_vars        = {ENV_NAME__USE_MINIO_AS_S3: 'True'}
        cls.random_aws_creds      = Temp__Random__AWS_Credentials(env_vars=cls.extra_env_vars).set_vars()
        cls.s3_db_server_requests = cbr_site_shared_objects.s3_db_server_requests()
        cls.s3_db_chat_threads    = cbr_site_shared_objects.s3_db_chat_threads()
        cls.server_name           = server_config__cbr_website.server_name()

        with cls.s3_db_chat_threads as _:                       # setup bucket for chat_threads
            assert _.using_minio() is True                      # confirm we are using Minio
            assert _.setup      () is _                         # this will create the temp bucket
            assert _.bucket_exists() is True

        with cls.s3_db_server_requests as _:                    # setup bucket for server_requests
            assert _.setup() is _
            assert _.bucket_exists() is True

    @classmethod
    def tearDownClass(cls):
        with cls.s3_db_chat_threads as _:                       # delete temp bucket for chat_threads
            assert _.using_minio() is True
            assert _.bucket_delete_all_files()
            assert _.bucket_delete() is True

        with cls.s3_db_server_requests as _:                    # delete temp bucket for server_requests
            assert _.using_minio() is True
            assert _.bucket_delete_all_files()
            assert _.bucket_delete() is True

        cls.random_aws_creds.restore_vars()

        server_config__cbr_website.cbr_config().cbr_website.s3_log_requests = False  # restore value of s3_log_requests
